pub enum SessionAuthMethod {
Anonymous,
StaticBearer {
principal: String,
token_fingerprint: String,
},
OAuthBearer {
principal: Option<String>,
issuer: Option<String>,
subject: Option<String>,
audience: Option<String>,
scopes: Vec<String>,
federated_claims: OAuthBearerFederatedClaims,
enterprise_identity: Option<EnterpriseIdentityContext>,
token_fingerprint: Option<String>,
},
}Expand description
Authentication method used to admit a session at the transport layer.
This is intentionally separate from Chio capability authorization. A session may be transport-authenticated and still be denied by capability or guard checks later during operation evaluation.
Variants
Implementations
Sourceimpl SessionAuthMethod
impl SessionAuthMethod
pub fn token_fingerprint(&self) -> Option<&str>