pub struct SignedCanonicalPayload { /* private fields */ }Expand description
Detached signature paired with the shared canonical bytes that were signed.
Implementations
Sourceimpl SignedCanonicalPayload
impl SignedCanonicalPayload
Sourcepub fn new(
signature: Signature,
canonical: Arc<CanonicalBytes>,
) -> SignedCanonicalPayload
pub fn new( signature: Signature, canonical: Arc<CanonicalBytes>, ) -> SignedCanonicalPayload
Build a signed canonical payload from a signature and shared bytes.
Sourcepub fn canonical(&self) -> &Arc<CanonicalBytes> ⓘ
pub fn canonical(&self) -> &Arc<CanonicalBytes> ⓘ
Borrow the shared canonical JSON bytes.
Sourcepub fn canonical_bytes(&self) -> &[u8] ⓘ
pub fn canonical_bytes(&self) -> &[u8] ⓘ
Borrow the signed canonical JSON byte slice.
Sourcepub fn into_parts(self) -> (Signature, Arc<CanonicalBytes>)
pub fn into_parts(self) -> (Signature, Arc<CanonicalBytes>)
Consume the payload into its signature and shared canonical bytes.
Sourcepub fn into_signature_and_bytes(self) -> (Signature, Vec<u8>)
pub fn into_signature_and_bytes(self) -> (Signature, Vec<u8>)
Consume the payload into the compatibility tuple shape.