Skip to main contentModule token
Source - CapabilityToken
- A Chio capability token. Scoped, time-bounded, cryptographically signed.
- CapabilityTokenAttenuationBody
- Attenuated capability signing input with attenuation and caveat fields.
- CapabilityTokenBody
- The body of a capability token, containing every field except the signature.
Used as the signing input.
- CapabilityTokenSigningBody
- Schema-aware capability-token signing input used by newly-issued tokens.
- CHIO_CAPABILITY_SCHEMA
- Current capability-token schema. Chio is unreleased, so pre-release
attenuation and delegation-binding fields are folded into this v1 shape.